@@ -73,7 +73,7 @@ assume that the code produced for a MachOp does not introduce new blocks.
 --
 -- (1) has the benefit that its interpretation is completely independent of the
 -- architecture. So, the mid-term plan is to migrate to this
--- interpretation/sematics.
+-- interpretation/semantics.
 
 data MachOp
   -- Integer operations (insensitive to signed/unsigned)
@@ -182,6 +182,10 @@ data MachOp
   | MO_VF_Mul  Length Width
   | MO_VF_Quot Length Width
 
+  -- | An atomic read with no memory ordering. Address msut
+  -- be naturally aligned.
+  | MO_RelaxedRead Width
+
   -- Alignment check (for -falignment-sanitisation)
   | MO_AlignmentCheck Int Width
   deriving (Eq, Show)
@@ -498,6 +502,7 @@ machOpResultType platform mop tys =
     MO_VF_Quot l w      -> cmmVec l (cmmFloat w)
     MO_VF_Neg  l w      -> cmmVec l (cmmFloat w)
 
+    MO_RelaxedRead r    -> cmmBits r
     MO_AlignmentCheck _ _ -> ty1
   where
     (ty1:_) = tys
@@ -592,6 +597,7 @@ machOpArgReps platform op =
     MO_VF_Quot _ r      -> [r,r]
     MO_VF_Neg  _ r      -> [r]
 
+    MO_RelaxedRead _    -> [wordWidth platform]
     MO_AlignmentCheck _ r -> [r]
 
 -----------------------------------------------------------------------------
@@ -690,8 +696,6 @@ data CallishMachOp
   | MO_SubIntC   Width
   | MO_U_Mul2    Width
 
-  | MO_ReadBarrier
-  | MO_WriteBarrier
   | MO_Touch         -- Keep variables live (when using interior pointers)
 
   -- Prefetch
@@ -721,6 +725,10 @@ data CallishMachOp
   | MO_BSwap Width
   | MO_BRev Width
 
+  | MO_AcquireFence
+  | MO_ReleaseFence
+  | MO_SeqCstFence
+
   -- | Atomic read-modify-write. Arguments are @[dest, n]@.
   | MO_AtomicRMW Width AtomicMachOp
   -- | Atomic read. Arguments are @[addr]@.
